pub enum ClientConfigError {
InvalidBaseUrl,
UnsupportedScheme,
NonOriginBaseUrl,
InvalidBearerToken,
ZeroLimit,
HttpClient,
}Expand description
Invalid client configuration detected before any network operation.
Variants
InvalidBaseUrl
Base URL is not syntactically valid.
UnsupportedScheme
Only explicit HTTP and HTTPS origins are supported.
NonOriginBaseUrl
Base URL must be one origin without credentials, query, fragment, or path prefix.
InvalidBearerToken
Bearer secret cannot be represented safely in one header.
ZeroLimit
Every local client bound must be positive.
HttpClient
Underlying HTTP client construction failed.