ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder { /* private fields */ }
Builder for a bounded public API client.

Implementations

Source

impl ClientBuilder

pub fn new(base_url: &str) -> Result<Self, ClientConfigError>

Parses one root HTTP(S) origin.

Errors

Rejects malformed URLs, non-HTTP schemes, credentials, query strings, fragments, and non-root paths.

pub fn bearer_token(self, token: &str) -> Result<Self, ClientConfigError>

Configures an opaque bearer token without retaining a second copy.

Errors

Rejects values that cannot be represented in one HTTP header.

pub fn timeout(self, timeout: Duration) -> Self

Sets the complete request/response deadline.

pub fn response_bytes(self, maximum: usize) -> Self

Sets the maximum complete JSON response bytes.

pub fn witness_bytes(self, maximum: usize) -> Self

Sets the maximum complete snapshot witness bytes.

pub fn build(self) -> Result<HyphaeClient, ClientConfigError>

Constructs the reusable client.

Errors

Rejects zero limits or an underlying HTTP client configuration error.